import json
import httpx
import asyncio


async def send_slack_channel_notification():
    message = {
        "blocks": [
            {
                "type": "divider"
            },
            {
                "type": "section",
                "text": {
                    "type": "mrkdwn",
                    "text": 'test'
                }
            }
        ]
    }

    slack_payload = json.dumps(message).encode("utf-8")
    slack_headers = [(b"content-type", b"application/json")]

    slack_url = "https://hooks.slack.com/services/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"


    async with httpx.AsyncClient() as client:
        await client.post(
                slack_url, headers=slack_headers, data=slack_payload
            )


asyncio.run(send_slack_channel_notification())




# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pychatz']

package_data = \
{'': ['*']}

install_requires = \
['httpx>=0.22.0,<0.23.0']

entry_points = \
{'console_scripts': ['pychatz = package_name:main']}

setup_kwargs = {
    'name': 'pychatz',
    'version': '1.0.1',
    'description': '',
    'long_description': 'TEST md\n',
    'author': 'Your Name',
    'author_email': 'you@example.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/MattiooFR/package_name',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
